@@ -21,6 +21,7 @@
 
 import os
 import logging
+from nl import conf
 
 logger = logging.getLogger('nl')
 here = os.path.join(os.path.dirname(__file__))
@@ -37,5 +38,5 @@ formatter = logging.Formatter('%(message)s')
 # formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
 hdlr.setFormatter(formatter)
 logger.addHandler(hdlr)
-logger.setLevel(logging.DEBUG)
+logger.setLevel(getattr(logging, conf.debug_level))
 
